﻿using System;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.FormsEdition;
using Xamarin.Forms;

namespace XFDemoTrail1
{
    public partial class App : Application
    {
        public App()
        {
            InitializeComponent();

            MapView mapView = new MapView();
            mapView.MapUnit = GeographyUnit.DecimalDegree;
            mapView.HorizontalOptions = LayoutOptions.Fill;
            mapView.HeightRequest = 600;
            mapView.CurrentExtent = new RectangleShape(-180, 90, 180, -90);
            var textColor = GeoColor.StandardColors.Fuchsia;
            var titleStyle = GetTextStyle("Title", 20, textColor);

            InMemoryFeatureLayer layer = new InMemoryFeatureLayer();
            layer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.City2;
            layer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = titleStyle;
            layer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            Random r = new Random();
            for (int i = 0; i < 20; i++)
            {
                double x = r.Next(-180, 180);
                double y = r.Next(-90, 90);
                var feature = new Feature(new PointShape(x, y));
                feature.ColumnValues.Add("Title", $"Label {i +1}");
                layer.InternalFeatures.Add(feature);
            }

            LayerOverlay layerOverlay = new LayerOverlay();
            layerOverlay.Layers.Add(layer);
            mapView.Overlays.Add(layerOverlay);

            // The root page of your application
            var content = new ContentPage { Title = "XFDemoTrail", Content = new Grid { Children = { mapView } } };

            MainPage = new NavigationPage(content);

            mapView.Refresh();
        }

        /// <summary> The get text style. </summary>
        /// <param name="columnName"> The column name. </param>
        /// <param name="textSize"> The text Size. </param>
        /// <param name="textColor"> The text Color. </param>
        /// <param name="fontStyles"> The font Styles. </param>
        /// <returns> The <see cref="TextStyle"/>. </returns>
        private static TextStyle GetTextStyle(
            string columnName,
            float textSize,
            GeoColor textColor,
            DrawingFontStyles fontStyles = DrawingFontStyles.Regular)
        {
            CustomLabelStyle textStyle = new CustomLabelStyle(
                                             columnName,
                                             new GeoFont("Arial", textSize, fontStyles),
                                             new GeoSolidBrush(textColor));
            textStyle.HaloPen = new GeoPen(GeoColor.StandardColors.White, 1);
            textStyle.Mask = new AreaStyle();
            textStyle.XOffsetInPixel = 10;
            textStyle.YOffsetInPixel = 10;
            textStyle.PointPlacement = PointPlacement.Center;
            textStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            return textStyle;
        }

        protected override void OnStart()
        {
            // Handle when your app starts
        }

        protected override void OnSleep()
        {
            // Handle when your app sleeps
        }

        protected override void OnResume()
        {
            // Handle when your app resumes
        }
    }
}
